@@ -20,13 +20,18 @@ from tamr_client._types import (
     AnyDataset,
     Attribute,
     AttributeType,
+    CategorizationProject,
     Dataset,
+    GoldenRecordsProject,
+    InputTransformation,
     Instance,
     MasteringProject,
     Operation,
     Project,
+    SchemaMappingProject,
     Session,
     SubAttribute,
+    Transformations,
     UnifiedDataset,
     URL,
     UsernamePasswordAuth,
@@ -36,14 +41,18 @@ from tamr_client._types import (
 ###############
 
 from tamr_client import attribute
+from tamr_client import categorization
 from tamr_client import dataset
+from tamr_client import golden_records
 from tamr_client import instance
 from tamr_client import mastering
 from tamr_client import operation
 from tamr_client import primary_key
 from tamr_client import project
 from tamr_client import response
+from tamr_client import schema_mapping
 from tamr_client import session
+from tamr_client import transformations
 from tamr_client.dataset import dataframe
 from tamr_client.dataset import record
 from tamr_client.exception import TamrClientException
