@@ -20,6 +20,13 @@ from tamr_client._types.dataset import AnyDataset, Dataset, UnifiedDataset
 from tamr_client._types.instance import Instance
 from tamr_client._types.json import JsonDict
 from tamr_client._types.operation import Operation
-from tamr_client._types.project import MasteringProject, Project
+from tamr_client._types.project import (
+    CategorizationProject,
+    GoldenRecordsProject,
+    MasteringProject,
+    Project,
+    SchemaMappingProject,
+)
 from tamr_client._types.session import Session
+from tamr_client._types.transformations import InputTransformation, Transformations
 from tamr_client._types.url import URL
